fnss.adapters.jfed.to_jfed — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »

# fnss.adapters.jfed.to_jfed

`to_jfed`(topology, path, testbed='wall1.ilabt.iminds.be', encoding='utf-8', prettyprint=True)

  Convert a topology object into an RSPEC file for jFed

  Parameters: | topology : Topology The topology object path : str The file to which the RSPEC will be written testbed : str, optional URI of the testbed to use encoding : str, optional The encoding of the target file prettyprint : bool, optional Indent the XML code in the output file

  Notes

  It currently supports only undirected topologies, if a topology is directed it is converted to undirected

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »